@@ -8,16 +8,22 @@ from ..__metadata__ import __version__
 from ..base import skedding, consoling
 
 
-def parseArgs():
-    """ Parse command line arguments"""
+def parseArgs(version=__version__):
+    """
+    Parse command line arguments
+
+    version parameter defaults to ioflo version
+    allows different version if parseArgs is embedded in another script
+
+    """
 
     d = "Runs ioflo. "
     d += "Example: ioflo -f filename -p period -v level -r -h -b 'mybehaviors.py'\n"
     p = argparse.ArgumentParser(description=d)
     p.add_argument('-V', '--version',
             action='version',
-            version=__version__,
-            help="Prints out version of ioflo.")
+            version=version,
+            help="Prints out version of ioflo script runner.")
     p.add_argument('-v', '--verbose',
             action='store',
             default='concise',
@@ -36,6 +42,11 @@ def parseArgs():
             const=True,
             default=False,
             help="Run skedder at realtime.")
+    p.add_argument('-R', '--retrograde',
+            action='store_const',
+            const=True,
+            default=True,
+            help="Shift skedder timers when retrograde clock detected.")
     p.add_argument('-n', '--name',
             action='store',
             default='skedder',
@@ -49,6 +60,10 @@ def parseArgs():
             nargs='*',
             default=None,
             help="Module name strings to external behavior packages.")
+    p.add_argument('-m', '--parsemode',
+            action='store',
+            default='',
+            help="FloScript parsing mode.")
     p.add_argument('-U', '--username',
             action='store',
             default='',
@@ -81,19 +96,20 @@ def parseArgs():
 
 def run(name="skedder",
         period=0.1,
-        stamp=0.0,
         real=False,
+        retro=True,
+        stamp=0.0,
         filepath="",
         behaviors=None,
+        mode=None,
         username="",
         password="",
-        mode=None,
-        houses=None,
-        metas=None,
-        preloads=None,
         verbose=0,
         consolepath="",
-        statistics=""):
+        statistics="",
+        houses=None,
+        metas=None,
+        preloads=None,        ):
     """ Run Skedder"""
     console = consoling.getConsole(verbosity=consoling.Console.Wordage[verbose],
                                    path=consolepath)
@@ -103,12 +119,13 @@ def run(name="skedder",
     skedder = skedding.Skedder(name=name,
                                period=period,
                                real=real,
+                               retro=retro,
                                stamp=stamp,
                                filepath=filepath,
                                behaviors=behaviors,
+                               mode=mode,
                                username=username,
                                password=password,
-                               mode=mode,
                                houses=houses,
                                metas=metas,
                                preloads=preloads)
