@@ -8,7 +8,8 @@ import struct
 from collections import deque
 import inspect
 
-from .odicting import odict
+from ..aid.sixing import *
+from ..aid.odicting import odict
 from .globaling import *
 
 from . import deeding
@@ -107,7 +108,7 @@ class Arbiter(deeding.Deed):
                 self.inimps.create(**{tag : imp}) #initialize importance if not exist
 
 
-    def expose(self):
+    def _expose(self):
         """prints out arbiter parameters
 
         """
