@@ -8,10 +8,10 @@ import struct
 from collections import deque
 import inspect
 
-
+from ..aid.sixing import *
 from .globaling import *
-from .odicting import odict
-from . import aiding
+from ..aid.odicting import odict
+from ..aid import aiding
 from . import excepting
 from . import registering
 from . import storing
@@ -27,7 +27,7 @@ class Need(acting.Actor):
     """
     Registry = odict()
 
-    def expose(self):
+    def _expose(self):
         """
         """
         print("Need %s " % (self.name))
@@ -52,7 +52,7 @@ class Need(acting.Actor):
             result = ( state > goal)
         elif comparison == '!=':
             try: #in case goal is string
-                result = ( state <= (goal - abs(tolerance)) or state >= (goal + abs(tolerance)) )
+                result = not ( (goal - abs(tolerance)) <= state <= (goal + abs(tolerance)) )
             except TypeError:
                 result = (goal != state)
         else:
@@ -70,42 +70,42 @@ class NeedAlways(Need):
 
 class NeedDone(Need):
     """NeedDone Need Special Need"""
-    def resolve(self, tasker, framer, frame, **kwa):
+    def _resolve(self, tasker, framer, frame, **kwa):
         """Resolves value (tasker) link that is passed in as tasker parm
-           resolved link is passed back to container act to update in act's parms
+           resolved link is passed back to container ._act to update in act's parms
         """
-        parms = super(NeedDone, self).resolve( **kwa)
+        parms = super(NeedDone, self)._resolve( **kwa)
         if framer:
             if framer == 'me':
-                framer = self.act.frame.framer
+                framer = self._act.frame.framer
             parms['framer'] = framer = framing.resolveFramer(framer,
-                                                            who=self.act.frame.name,
+                                                            who=self._act.frame.name,
                                                             desc='need done',
                                                             contexts=[],
-                                                            human=self.act.human,
-                                                            count=self.act.count)
+                                                            human=self._act.human,
+                                                            count=self._act.count)
 
         if frame: # framer required
             if frame == 'me':
-                frame = self.act.frame
+                frame = self._act.frame
             parms['frame'] = frame = framing.resolveFrameOfFramer(frame,
                                                                   framer,
-                                                                  who=self.act.frame.name,
+                                                                  who=self._act.frame.name,
                                                                   desc='need done',
-                                                                  human=self.act.human,
-                                                                  count=self.act.count)
+                                                                  human=self._act.human,
+                                                                  count=self._act.count)
 
 
         if tasker not in ['any', 'all']:
             parms['tasker'] = tasker = tasking.resolveTasker(tasker,
-                                                             who=self.act.frame.name,
+                                                             who=self._act.frame.name,
                                                              desc='need done',
                                                              contexts=[],
-                                                             human=self.act.human,
-                                                             count=self.act.count)
+                                                             human=self._act.human,
+                                                             count=self._act.count)
 
 
-        return parms #return items are updated in original act parms
+        return parms #return items are updated in original ._act parms
 
     def action(self, tasker, framer, frame, **kw):
         """
@@ -130,21 +130,21 @@ class NeedDone(Need):
 class NeedStatus(Need):
     """NeedStatus Need Special Need """
 
-    def resolve(self, tasker, **kwa):
+    def _resolve(self, tasker, **kwa):
         """Resolves value (tasker) link that is passed in as parm
-           resolved link is passed back to container act to update in act's parms
+           resolved link is passed back to container ._act to update in act's parms
         """
-        parms = super(NeedStatus, self).resolve( **kwa)
+        parms = super(NeedStatus, self)._resolve( **kwa)
         if tasker == 'me':
-            tasker = self.act.frame.framer
+            tasker = self._act.frame.framer
 
         parms['tasker'] = tasker = tasking.resolveTasker(tasker,
                                                          who=self.name,
                                                          desc='need status tasker',
                                                          contexts=[],
-                                                         human=self.act.human,
-                                                         count=self.act.count)
-        return parms #return items are updated in original act parms
+                                                         human=self._act.human,
+                                                         count=self._act.count)
+        return parms #return items are updated in original ._act parms
 
     def action(self, tasker, status, **kw):
         """
@@ -165,7 +165,7 @@ class NeedState(Need):
     """
     NeedState is a base class for Needs that must resolve a state share ref
     """
-    def resolve(self, state, stateField, **kwa):
+    def _resolve(self, state, stateField, **kwa):
         """
         Resolves state share
 
@@ -173,10 +173,10 @@ class NeedState(Need):
             state       share path of state
             stateField  state share field name
         """
-        parms = super(NeedState, self).resolve( **kwa)
+        parms = super(NeedState, self)._resolve( **kwa)
 
         #convert state path to share and create field if necessary
-        parms['state'] = state = self.resolvePath(ipath=state,
+        parms['state'] = state = self._resolvePath(ipath=state,
                                                   warn=True) # now a share
 
         if not stateField: #default rules for field
@@ -188,7 +188,7 @@ class NeedState(Need):
                     msg = ("ResolveError: Can't determine field for state"
                           " '{0}'".format(state.name))
                     raise excepting.ResolveError(msg, 'state', self.name,
-                                            self.act.human, self.act.count)
+                                            self._act.human, self._act.count)
             else:
                 stateField = 'value'
 
@@ -199,7 +199,7 @@ class NeedState(Need):
 
         parms['stateField'] = stateField
 
-        return parms #return items are updated in original act parms
+        return parms #return items are updated in original ._act parms
 
 class NeedBoolean(NeedState):
     """NeedBoolean Need Special Need
@@ -250,7 +250,7 @@ class NeedIndirect(NeedState):
 
        if state comparison goal [+- tolerance]
     """
-    def resolve(self, goal, goalField, **kwa):
+    def _resolve(self, goal, goalField, **kwa):
         """
         Resolves state share
 
@@ -261,10 +261,10 @@ class NeedIndirect(NeedState):
             tolerance   tolerance value
 
         """
-        parms = super(NeedIndirect, self).resolve( **kwa)
+        parms = super(NeedIndirect, self)._resolve( **kwa)
 
         #convert goal path to share and create field if necessary
-        parms['goal'] = goal = self.resolvePath(ipath=goal,
+        parms['goal'] = goal = self._resolvePath(ipath=goal,
                                                 warn=True) # now a share
 
         if not goalField: #default rules for field
@@ -284,7 +284,7 @@ class NeedIndirect(NeedState):
 
         parms['goalField'] = goalField
 
-        return parms #return items are updated in original act parms
+        return parms #return items are updated in original ._act parms
 
     def action(self, state, stateField, comparison, goal, goalField, tolerance, **kwa):
         """ Check if state[field] comparison to goal[goalField] +- tolerance is True
@@ -310,7 +310,7 @@ class NeedMarker(Need):
     Special Need
 
     """
-    def resolve(self, share, frame, marker, **kwa):
+    def _resolve(self, share, frame, marker, **kwa):
         """
         Resolves frame name link and then
            inserts marker as first enact in the resolved frame
@@ -322,21 +322,21 @@ class NeedMarker(Need):
             marker      only used in resolvelinks
 
         """
-        parms = super(NeedMarker, self).resolve( **kwa)
+        parms = super(NeedMarker, self)._resolve( **kwa)
 
-        framer = self.act.frame.framer
+        framer = self._act.frame.framer
 
         if frame == 'me':
-            frame = self.act.frame
+            frame = self._act.frame
 
         parms['frame'] = frame = framing.resolveFrameOfFramer(frame,
                                                               framer,
                                                               who=self.name,
                                                               desc='need marker',
-                                                              human=self.act.human,
-                                                              count=self.act.count)
+                                                              human=self._act.human,
+                                                              count=self._act.count)
 
-        parms['share'] = share = self.resolvePath(ipath=share,
+        parms['share'] = share = self._resolvePath(ipath=share,
                                                   warn=True) # now a share
 
         if not share.marks.get(frame.name):
@@ -355,14 +355,14 @@ class NeedMarker(Need):
             if marker not in acting.Actor.Registry:
                 msg = "ResolveError: Bad need marker link"
                 raise excepting.ResolveError(msg, marker, self.name,
-                                self.act.human, self.act.count)
+                                self._act.human, self._act.count)
 
             markerParms = dict(share=share, frame=frame.name)
             parms['marker'] = marker = acting.Act(  actor=marker,
                                                     registrar=acting.Actor,
                                                     parms=markerParms,
-                                                    human=self.act.human,
-                                                    count=self.act.count)
+                                                    human=self._act.human,
+                                                    count=self._act.count)
 
             frame.insertEnact(marker)
             console.profuse("     Added {0} {1} with {2} in {3}\n".format(
@@ -372,7 +372,7 @@ class NeedMarker(Need):
                 marker.parms['frame']))
             marker.resolve()
 
-        return parms #return items are updated in original act parms
+        return parms #return items are updated in original ._act parms
 
 class NeedUpdate(NeedMarker):
     """ NeedUpdate Need Special Need """
