@@ -11,11 +11,12 @@ import io
 
 from collections import deque
 
-
-from .odicting import odict
+from ..aid.sixing import *
+from ..aid.odicting import odict
 from .globaling import *
 
-from . import aiding
+from ..aid import aiding, nonblocking
+
 #from .aiding import b
 from . import tasking
 
@@ -59,7 +60,7 @@ class Server(tasking.Tasker):
 
         #create socket server
         self.sha = sha
-        self.server = aiding.SocketUdpNb(ha=sha, path='') #reopened by runner
+        self.server = nonblocking.SocketUdpNb(ha=sha) #reopened by runner
         self.dha = dha #set up destination address
 
         self.prefix = prefix #prefix to log directory for server
@@ -76,7 +77,7 @@ class Server(tasking.Tasker):
         if sha is not None:
             self.sha = sha
             if not self.server:
-                self.server = aiding.SocketUdpNb(ha=sha, path='') #reopened by runner
+                self.server = nonblocking.SocketUdpNb(ha=sha, path='') #reopened by runner
             self.server.ha = sha
 
         if dha is not None:
@@ -258,53 +259,3 @@ class Server(tasking.Tasker):
             self.desire = ABORT
             self.status = ABORTED
             self.close()
-
-
-def TestOpenStuff():
-    """    """
-    import ioflo.base.storing as storing
-
-
-    storing.Store.Clear() #clear registry
-    s1 = ServerTask(store = storing.Store())
-    s2 = ServerTask(store = storing.Store())
-
-    print(s1.server.reopen())
-    print(s2.server.reopen())
-
-
-def Test(verbose = False):
-    """Module self test
-
-
-
-    """
-    import ioflo.base.storing as storing
-    import ioflo.base.tasking as tasking
-
-    storing.Store.Clear() #clear registry
-    tasking.Tasker.Clear()
-
-    s = Server(store = storing.Store())
-
-    s.store.expose()
-
-    print("ready to go")
-    status = s.start()
-
-    while (not (status == STOPPED or status == ABORTED)):
-        try:
-            status = s.run()
-
-        except KeyboardInterrupt: #CNTL-C shutdown skedder
-            print("    Keyboard Interrupt manual shutdown of taskers ...")
-            s.server.close()
-
-
-            break
-
-
-
-if __name__ == "__main__":
-    Test()
-
